@@ -98,11 +98,11 @@ function `string-to-number'."
 
 (defcustom eshell-ange-ls-uids nil
   "*List of user/host/id strings, used to determine remote ownership."
-  :type '(list (cons :tag "Host/User Pair"
-		     (string :tag "Hostname")
-		     (repeat (cons :tag "User/UID List"
-				   (string :tag "Username")
-				   (repeat :tag "UIDs" string)))))
+  :type '(repeat (cons :tag "Host/User Pair"
+		       (string :tag "Hostname")
+		       (repeat (cons :tag "User/UID List"
+				     (string :tag "Username")
+				     (repeat :tag "UIDs" string)))))
   :group 'eshell-util)
 
 ;;; Internal Variables:
